numpy.polynomial.Laguerre
=========================

.. currentmodule:: numpy.polynomial

.. autoclass:: Laguerre

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Laguerre.__init__
         Laguerre.convert
         Laguerre.copy
         Laguerre.cutdeg
         Laguerre.degree
         Laguerre.deriv
         Laguerre.has_samecoef
         Laguerre.has_samedomain
         Laguerre.has_samewindow
         Laguerre.integ
         Laguerre.linspace
         Laguerre.mapparms
         Laguerre.roots
         Laguerre.trim
         Laguerre.truncate



   

